@@ -6,16 +6,17 @@
 #' @param model Model object. Estimated model object as returned by function \link{apollo_estimate}.
 #' @param modelOutput_settings List of options. It can include the following.
 #'                             \itemize{
-#'                               \item \code{printClassical}: Boolean. TRUE for printing classical standard errors. TRUE by default.
-#'                               \item \code{printPVal}: Boolean or Scalar. TRUE or 1 for printing p-values for one-sided test, 2 for printing p-values for two-sided test, FALSE for not printing p-values. FALSE by default.
-#'                               \item \code{printT1}: Boolean. If TRUE, t-test for H0: apollo_beta=1 are printed. FALSE by default.
-#'                               \item \code{printDataReport}: Boolean. TRUE for printing summary of choices in database and other diagnostics. FALSE by default.
-#'                               \item \code{printModelStructure}: Boolean. TRUE for printing model structure. TRUE by default.
-#'                               \item \code{printCovar}: Boolean. TRUE for printing parameters covariance matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. FALSE by default.
-#'                               \item \code{printCorr}: Boolean. TRUE for printing parameters correlation matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. FALSE by default.
-#'                               \item \code{printOutliers}: Boolean or Scalar. TRUE for printing 20 individuals with worst average fit across observations. FALSE by default. If Scalar is given, this replaces the default of 20.
-#'                               \item \code{printChange}: Boolean. TRUE for printing difference between starting values and estimates. FALSE by default.
-#'                               \item \code{printFunctions}: Boolean. TRUE for printing apollo_control, apollo_randCoeff (when available), apollo_lcPars (when available) and apollo_probabilities. FALSE by default.
+#'                               \item \code{printFixed}: Logical. TRUE for printing fixed parameters among estimated parameter. TRUE by default.
+#'                               \item \code{printClassical}: Logical. TRUE for printing classical standard errors. TRUE by default.
+#'                               \item \code{printPVal}: Logical or Scalar. TRUE or 1 for printing p-values for one-sided test, 2 for printing p-values for two-sided test, FALSE for not printing p-values. FALSE by default.
+#'                               \item \code{printT1}: Logical. If TRUE, t-test for H0: apollo_beta=1 are printed. FALSE by default.
+#'                               \item \code{printDataReport}: Logical. TRUE for printing summary of choices in database and other diagnostics. FALSE by default.
+#'                               \item \code{printModelStructure}: Logical. TRUE for printing model structure. TRUE by default.
+#'                               \item \code{printCovar}: Logical. TRUE for printing parameters covariance matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. FALSE by default.
+#'                               \item \code{printCorr}: Logical. TRUE for printing parameters correlation matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. FALSE by default.
+#'                               \item \code{printOutliers}: Logical or Scalar. TRUE for printing 20 individuals with worst average fit across observations. FALSE by default. If Scalar is given, this replaces the default of 20.
+#'                               \item \code{printChange}: Logical. TRUE for printing difference between starting values and estimates. FALSE by default.
+#'                               \item \code{printFunctions}: Logical. TRUE for printing apollo_control, apollo_randCoeff (when available), apollo_lcPars (when available) and apollo_probabilities. FALSE by default.
 #'                             }
 #' @return A matrix of coefficients, s.d. and t-tests (invisible)
 #' @export
@@ -37,6 +38,7 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   if(is.null(modelOutput_settings[["printOutliers"]])) modelOutput_settings[["printOutliers"]] = FALSE
   if(is.null(modelOutput_settings[["printChange"]])) modelOutput_settings[["printChange"]] = FALSE
   if(is.null(modelOutput_settings[["printFunctions"]])) modelOutput_settings[["printFunctions"]] = FALSE
+  if(is.null(modelOutput_settings[["printFixed"]])) modelOutput_settings[["printFixed"]] = TRUE
   
   printClassical   = modelOutput_settings[["printClassical"]]
   printPVal        = modelOutput_settings[["printPVal"]]
@@ -47,6 +49,7 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   printOutliers    = modelOutput_settings[["printOutliers"]]
   printChange      = modelOutput_settings[["printChange"]]
   printFunctions   = modelOutput_settings[["printFunctions"]]
+  printFixed       = modelOutput_settings[["printFixed"]]
   
   if(length(model$scaling)>0 && !anyNA(model$scaling) && !all(model$scaling==1)){
     scaling_used=TRUE
@@ -78,7 +81,15 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   cat("Estimation method                : ", model$estimationRoutine, "\n", sep="")
   if(!apollo_control$HB) cat("Model diagnosis                  : ",model$message,"\n", sep="")
   cat("Number of individuals            : ", model$nIndivs,"\n", sep="")
-  cat("Number of observations           : ", model$nObs,"\n\n", sep="")
+  cat("Number of rows in database       : ", model$nObs,"\n", sep="")
+  if(!is.null(model$nObsTot)){
+    cat('Number of modelled outcomes      : ', sum(model$nObsTot), '\n', sep='')
+    if(length(model$nObsTot)>1) for(i in names(model$nObsTot)){
+      if(nchar(i)>26) txt <- substr(i, 1, 26) else txt <- i # max 26 characters for the component name
+      if(nchar(txt)<26) txt <- paste0(c(rep(' ', 26 - nchar(txt)), txt), collapse='')
+      cat('       ', txt, ': ', model$nObsTot[i], '\n', sep='')
+    }; cat('\n')
+  }
   cat("Number of cores used             : ",model$apollo_control$nCores,"\n")
   if(model$apollo_control$mixing){
     d <- model$apollo_draws
@@ -286,7 +297,8 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
     cat("Adj.Rho-square (0)               : Not applicable\n")
   }
   cat("AIC                              : ",round(-2*model$maximum + 2*nFreeParams,2),"\n")
-  cat("BIC                              : ",round(-2*model$maximum + nFreeParams*log(model$nObs),2),"\n")
+  if(!is.null(model$nObsTot)) tmp <- sum(model$nObsTot) else tmp <- model$nObs
+  cat("BIC                              : ",round(-2*model$maximum + nFreeParams*log(tmp),2),"\n")
   
   cat("\n")
   if(length(model$LLout)>1){
@@ -330,6 +342,7 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   if(scaling_used) apollo_print("These outputs have had the scaling used in estimation applied to them.")
   cat("Estimates:\n")
   if(nrow(output)>options("max.print")) options(max.print=nrow(output)+100)
+  if(!printFixed && length(model$apollo_fixed)>0) output <- output[!(rownames(output) %in% model$apollo_fixed),]
   apollo_print(output) #print(output, digits=4)
   cat('\n')
   
@@ -412,7 +425,7 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   if(printChange){
     cat("\nChanges in parameter estimates from starting values:\n")
     tmp <- cbind(model$apollo_beta, model$estimate[names(model$apollo_beta)],
-               model$estimate[names(model$apollo_beta)]-model$apollo_beta)
+                 model$estimate[names(model$apollo_beta)]-model$apollo_beta)
     colnames(tmp) <- c("Initial", "Estimate", "Difference")
     apollo_print(tmp)
   }
@@ -436,12 +449,12 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
     cat("\n--------------\n")
     cat(model$hessianMethodsAttempted)
     cat("\n")
-  if(!is.null(model$scaling) && !all(model$scaling==1)){
-    cat("\nScaling in estimation")
-    cat("\n--------------\n")
-    txt=as.matrix(model$scaling)
-    colnames(txt)="Value"
-    print(txt)}
+    if(!is.null(model$scaling) && !all(model$scaling==1)){
+      cat("\nScaling in estimation")
+      cat("\n--------------\n")
+      txt=as.matrix(model$scaling)
+      colnames(txt)="Value"
+      print(txt)}
     if(!is.null(model$hessianScaling) && !all(model$hessianScaling==1)){
       cat("\nScaling used in computing Hessian")
       cat("\n--------------\n")
@@ -449,20 +462,20 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
       colnames(txt)="Value"
       print(txt)}
     if(is.function(model$apollo_randCoeff)){
-    cat("\n\napollo_randCoeff")
-    cat("\n----------------\n")
-    txt=capture.output(print(model$apollo_randCoeff))
-    cat(txt[1:(length(txt)-1)],sep="\n")}
-  if(is.function(model$apollo_lcPars)){
-    cat("\n\napollo_lcPars")
-    cat("\n-------------\n")
-    txt=capture.output(print(model$apollo_lcPars))
-    cat(txt[1:(length(txt)-1)],sep="\n")}
-  cat("\n\napollo_probabilities")
-  cat("\n--------------------\n")
-  txt=capture.output(print(model$apollo_probabilities))
-  cat(txt[1:(length(txt)-1)],sep="\n")
-    }
+      cat("\n\napollo_randCoeff")
+      cat("\n----------------\n")
+      txt=capture.output(print(model$apollo_randCoeff))
+      cat(txt[1:(length(txt)-1)],sep="\n")}
+    if(is.function(model$apollo_lcPars)){
+      cat("\n\napollo_lcPars")
+      cat("\n-------------\n")
+      txt=capture.output(print(model$apollo_lcPars))
+      cat(txt[1:(length(txt)-1)],sep="\n")}
+    cat("\n\napollo_probabilities")
+    cat("\n--------------------\n")
+    txt=capture.output(print(model$apollo_probabilities))
+    cat(txt[1:(length(txt)-1)],sep="\n")
+  }
   
   invisible(output)
 }
